Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(44)

Unified Diff: cc/trees/layer_tree_host_impl_unittest.cc

Issue 608223002: [Android]Increase Scrollbar fade delay on Resize. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/trees/layer_tree_host_impl_unittest.cc
diff --git a/cc/trees/layer_tree_host_impl_unittest.cc b/cc/trees/layer_tree_host_impl_unittest.cc
index 92087fe361ddf662e5bc02633670f28f1c9c8c2e..6b3e1384c09f9feecc69959f345296dfc19da838 100644
--- a/cc/trees/layer_tree_host_impl_unittest.cc
+++ b/cc/trees/layer_tree_host_impl_unittest.cc
@@ -1398,6 +1398,7 @@ TEST_F(LayerTreeHostImplTest, ScrollbarFadePinchZoomScrollbars) {
LayerTreeSettings settings;
settings.scrollbar_animator = LayerTreeSettings::LinearFade;
settings.scrollbar_fade_delay_ms = 20;
+ settings.scrollbar_fade_resize_delay_ms = 50;
settings.scrollbar_fade_duration_ms = 20;
settings.use_pinch_zoom_scrollbars = true;
@@ -1434,12 +1435,12 @@ TEST_F(LayerTreeHostImplTest, ScrollbarFadePinchZoomScrollbars) {
// Make page scale > min so that subsequent scrolls will trigger fades.
host_impl_->active_tree()->SetPageScaleDelta(1.1f);
// After a scroll, a fade animation should be scheduled about 20ms from now.
aelias_OOO_until_Jul13 2014/10/01 18:41:26 "After pinch causes a scrollbar resize,"
MuVen 2014/10/02 08:42:47 Done.
host_impl_->ScrollBegin(gfx::Point(), InputHandler::Wheel);
host_impl_->ScrollBy(gfx::Point(), gfx::Vector2dF(5, 0));
host_impl_->ScrollEnd();
did_request_redraw_ = false;
- EXPECT_LT(base::TimeDelta::FromMilliseconds(19),
+ EXPECT_LT(base::TimeDelta::FromMilliseconds(49),
requested_scrollbar_animation_delay_);
EXPECT_FALSE(did_request_animate_);
requested_scrollbar_animation_delay_ = base::TimeDelta();
@@ -1434,12 +1435,12 @@ TEST_F(LayerTreeHostImplTest, ScrollbarFadePinchZoomScrollbars) {
// Make page scale > min so that subsequent scrolls will trigger fades.
host_impl_->active_tree()->SetPageScaleDelta(1.1f);
- // After a scroll, a fade animation should be scheduled about 20ms from now.
+ // After a scroll, a fade animation should be scheduled about 50ms from now.
aelias_OOO_until_Jul13 2014/10/01 18:41:26 "After pinch causes a scrollbar resize,"
MuVen 2014/10/02 08:42:47 Done.

Powered by Google App Engine
This is Rietveld 408576698